package com.ym.mec.web.controller;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ym.mec.biz.dal.entity.ManagerDownload;
import com.ym.mec.biz.dal.page.ManagerDownloadQueryInfo;
import com.ym.mec.biz.service.ManagerDownloadService;
import com.ym.mec.biz.service.SysUserService;
import com.ym.mec.common.controller.BaseController;
import com.ym.mec.common.exception.BizException;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

@RequestMapping("${app-config.url.web:}/managerDownload")
@Api(tags = "下载列表")
@RestController
public class ManagerDownloadController extends BaseController {

    @Autowired
    private ManagerDownloadService managerDownloadService;
    @Autowired
    private SysUserService sysUserService;

    @ApiOperation(value = "分页查询列表")
    @GetMapping("/queryPage")
    //@PreAuthorize("@pcs.hasPermissions('managerDownload/queryPage')")
    public Object queryPage(ManagerDownloadQueryInfo queryInfo) {
    	long start = System.currentTimeMillis();
        queryInfo.setUserId(sysUserService.getUserId());
        System.out.println("**************************** Feign Client 耗时：" + (System.currentTimeMillis() - start) +"ms ******************************");
        start = System.currentTimeMillis();
        com.ym.mec.common.page.PageInfo<ManagerDownload> r = managerDownloadService.queryPage(queryInfo);
        System.out.println("**************************** 查询耗时：" + (System.currentTimeMillis() - start) +"ms ******************************");
        return succeed(r);
    }

    @ApiOperation(value = "删除")
    @PostMapping("/del/{id}")
    @PreAuthorize("@pcs.hasPermissions('managerDownload/del')")
    public Object del(@ApiParam(value = "下载记录id", required = true) @PathVariable("id") Integer id) {
        return succeed(managerDownloadService.delete(id));
    }

    @ApiOperation(value = "删除")
    @PostMapping("/batchDel")
    @PreAuthorize("@pcs.hasPermissions('managerDownload/batchDel')")
    public Object batchDel(String ids) {
        if(StringUtils.isEmpty(ids)){
            throw new BizException("参数校验失败");
        }
        managerDownloadService.batchDel(ids);
        return succeed();
    }

}
